# Site Craft CLI

A simple CLI tool to create and manage web project structure.

## Features

- Create web project
- Add HTML files
- Add CSS files
- Add JS files
- Auto link files

## Usage

auto create-web
auto add-css
auto add-js
